import React from "react";
import { GoogleViz, GoogleChartWrapperChartType, ChartWrapperOptions, GoogleChartWrapper, GoogleVizEventName, GoogleChartAction, GoogleDataTableRow, GoogleDataTableColumn, GoogleChartVersion, GoogleChartPackages } from "./types";
export declare type ReactGoogleChartEvent = {
    eventName: GoogleVizEventName;
    callback: (chartWrapper: GoogleChartWrapper) => void;
};
export declare type ReactGoogleChartProps = {
    height: string | number;
    width: string | number;
    graphID?: string;
    chartType: GoogleChartWrapperChartType;
    options?: Partial<ChartWrapperOptions["options"]>;
    loader?: JSX.Element;
    data?: any[];
    rows?: GoogleDataTableRow[];
    columns?: GoogleDataTableColumn[];
    chartActions?: GoogleChartAction[];
    events?: ReactGoogleChartEvent[];
    chartVersion?: GoogleChartVersion;
    chartPackages?: GoogleChartPackages[];
    chartLanguage?: string;
    mapsApiKey?: string;
    graph_id?: string;
    legendToggle?: boolean;
    legend_toggle?: boolean;
    getChartWrapper?: (chartWrapper: GoogleChartWrapper) => void;
};
export declare type ReactGoogleChartState = {
    loadingStatus: "loading" | "errored" | "ready";
    google: null | GoogleViz;
    hiddenColumns: string[];
};
export declare const chartDefaultProps: {
    graph_id: string | null;
    legend_toggle: boolean;
    graphID: null;
    options: Partial<{
        width: number;
        height: number;
        is3D: boolean;
        title: string;
        backgroundColor: string;
        hAxis?: {
            minValue?: number | undefined;
            maxValue?: number | undefined;
            ticks?: number[] | undefined;
            title?: string | undefined;
            viewWindow?: {
                max?: number | undefined;
                min?: number | undefined;
            } | undefined;
        } | undefined;
        vAxis?: {
            minValue?: number | undefined;
            maxValue?: number | undefined;
            ticks?: number[] | undefined;
            title?: string | undefined;
            viewWindow?: {
                max?: number | undefined;
                min?: number | undefined;
            } | undefined;
        } | undefined;
        legend: string;
        colors: string[];
    }>;
    data: null;
    rows: import("../../../../../../../../../../Users/rn/Code/et3arraf-deployed/et3-mono-repo-2/farah/tensorflowjs-playground/src/react-google-charts/src/types").GoogleDataTableCell[][] | null;
    columns: GoogleDataTableColumn[] | null;
    events: ReactGoogleChartEvent[] | null;
    legendToggle: boolean;
    chartActions: GoogleChartAction[] | null;
    getChartWrapper: (chartWrapper: GoogleChartWrapper) => void;
};
export declare type ReactGoogleChartPropsWithDefaults = typeof chartDefaultProps & ReactGoogleChartProps;
export declare class Chart extends React.Component<ReactGoogleChartProps, ReactGoogleChartState> {
    state: ReactGoogleChartState;
    graphID: null | string;
    chartWrapper: GoogleChartWrapper | null;
    static defaultProps: {
        graph_id: string | null;
        legend_toggle: boolean;
        graphID: null;
        options: Partial<{
            width: number;
            height: number;
            is3D: boolean;
            title: string;
            backgroundColor: string;
            hAxis?: {
                minValue?: number | undefined;
                maxValue?: number | undefined;
                ticks?: number[] | undefined;
                title?: string | undefined;
                viewWindow?: {
                    max?: number | undefined;
                    min?: number | undefined;
                } | undefined;
            } | undefined;
            vAxis?: {
                minValue?: number | undefined;
                maxValue?: number | undefined;
                ticks?: number[] | undefined;
                title?: string | undefined;
                viewWindow?: {
                    max?: number | undefined;
                    min?: number | undefined;
                } | undefined;
            } | undefined;
            legend: string;
            colors: string[];
        }>;
        data: null;
        rows: import("../../../../../../../../../../Users/rn/Code/et3arraf-deployed/et3-mono-repo-2/farah/tensorflowjs-playground/src/react-google-charts/src/types").GoogleDataTableCell[][] | null;
        columns: GoogleDataTableColumn[] | null;
        events: ReactGoogleChartEvent[] | null;
        legendToggle: boolean;
        chartActions: GoogleChartAction[] | null;
        getChartWrapper: (chartWrapper: GoogleChartWrapper) => void;
    };
    private getGraphID;
    private draw;
    private grayOutHiddenColumns;
    componentDidMount(): void;
    componentDidUpdate(prevProps: ReactGoogleChartPropsWithDefaults, prevState: ReactGoogleChartState): void;
    componentWillUnmount(): void;
    private setChartActions;
    private getColumnID;
    private listenToChartEvents;
    private listenToLegendToggle;
    private handleGoogleChartsLoaderScriptLoaded;
    private handleGoogleChartsLoaderScriptErrored;
    render(): JSX.Element;
}
